@@ -71,7 +71,7 @@ fi
 # set defaults, if nothing given
 [ "${KERNEL}" = "" ] && KERNEL="$(uname -r)"
 [ "${LTS_KERNEL}" = "" ] && LTS_KERNEL="2.6.32-lts"
-[ "${RELEASENAME}" = "" ] && RELEASENAME="2k11-R5"
+[ "${RELEASENAME}" = "" ] && RELEASENAME="2k11-R6"
 [ "${IMAGENAME}" = "" ] && IMAGENAME="Archlinux-allinone-$(date +%Y.%m)"
 
 ALLINONE="$(mktemp -d /tmp/allinone.XXX)"
@@ -81,6 +81,29 @@ mkdir "${ALLINONE}/arch"
 mkdir -p "${ALLINONE}/boot/syslinux"
 mkdir -p "${ALLINONE}/packages/"
 
+_merge_initramfs_files() {
+	
+	# extract the initramfs files
+	mkdir  "${CORE}/tmp"/initrd
+	cd "${CORE}/tmp"/initrd
+	bsdtar xf "${CORE}/tmp"/*/boot/initrd.img
+	bsdtar xf "${CORE_LTS}/tmp"/*/boot/initrd.img
+	mkdir  "${CORE64}/tmp"/initrd
+	cd "${CORE64}/tmp"/initrd
+	bsdtar xf "${CORE64}/tmp"/*/boot/initrd.img
+	bsdtar xf "${CORE64_LTS}/tmp"/*/boot/initrd.img
+	
+	# merge them into one file for each architecture
+	cd  "${CORE}/tmp"/initrd
+	find . -print0 | bsdcpio -0oH newc | lzma > "${CORE}/tmp"/initrd.img
+	
+	cd  "${CORE64}/tmp"/initrd
+	find . -print0 | bsdcpio -0oH newc | lzma > "${CORE64}/tmp"/initrd64.img
+	
+	cd "${WD}/"
+	
+}
+
 _prepare_kernel_initramfs_files() {
 	
 	# place kernels and memtest
@@ -91,10 +114,8 @@ _prepare_kernel_initramfs_files() {
 	mv "${CORE}/tmp"/*/boot/memtest "${ALLINONE}/boot/memtest"
 	
 	# place initramfs files
-	mv "${CORE}/tmp"/*/boot/initrd.img "${ALLINONE}/boot/initrd.img"
-	mv "${CORE_LTS}/tmp"/*/boot/initrd.img "${ALLINONE}/boot/initrdlts.img"
-	mv "${CORE64}/tmp"/*/boot/initrd.img "${ALLINONE}/boot/initrd64.img"
-	mv "${CORE64_LTS}/tmp"/*/boot/initrd.img "${ALLINONE}/boot/initrd64lts.img"
+	mv "${CORE}/tmp"/initrd.img "${ALLINONE}/boot/initrd.img"
+	mv "${CORE64}/tmp"/initrd64.img "${ALLINONE}/boot/initrd64.img"
 	
 }
 
@@ -164,14 +185,14 @@ _prepare_grub2_uefi_x86_64_iso_files() {
 	cat << EOF > "${memdisk_64_dir}/efi/grub2/grub.cfg"
 set _UEFI_ARCH="x86_64"
 
-search --file --no-floppy --set=efi64 /efi/grub2/x86_64-efi/grub.cfg
-set prefix=(\${efi64})/efi/grub2/x86_64-efi
+search --file --no-floppy --set=uefi64 /efi/grub2/x86_64-efi/grub.cfg
+set prefix=(\${uefi64})/efi/grub2/x86_64-efi
 source \${prefix}/grub.cfg
 EOF
 	
 	cat << EOF > "${ALLINONE}/efi/grub2/x86_64-efi/grub.cfg"
-search --file --no-floppy --set=efi64 /efi/grub2/x86_64-efi/grub.cfg
-source (\${efi64})/efi/grub2/grub.cfg
+search --file --no-floppy --set=uefi64 /efi/grub2/x86_64-efi/grub.cfg
+source (\${uefi64})/efi/grub2/grub.cfg
 EOF
 	
 	tar -C "${memdisk_64_dir}" -cf - efi > "${memdisk_64_img}"
@@ -201,14 +222,14 @@ _prepare_grub2_uefi_i386_iso_files() {
 	cat << EOF > "${memdisk_32_dir}/efi/grub2/grub.cfg"
 set _UEFI_ARCH="i386"
 
-search --file --no-floppy --set=efi32 /efi/grub2/i386-efi/grub.cfg
-set prefix=(\${efi32})/efi/grub2/i386-efi
+search --file --no-floppy --set=uefi32 /efi/grub2/i386-efi/grub.cfg
+set prefix=(\${uefi32})/efi/grub2/i386-efi
 source \${prefix}/grub.cfg
 EOF
 	
 	cat << EOF > "${ALLINONE}/efi/grub2/i386-efi/grub.cfg"
-search --file --no-floppy --set=efi32 /efi/grub2/i386-efi/grub.cfg
-source (\${efi32})/efi/grub2/grub.cfg
+search --file --no-floppy --set=uefi32 /efi/grub2/i386-efi/grub.cfg
+source (\${uefi32})/efi/grub2/grub.cfg
 EOF
 	
 	tar -C "${memdisk_32_dir}" -cf - efi > "${memdisk_32_img}"
@@ -238,7 +259,7 @@ _prepare_grub2_uefi_iso_files() {
 	
 	## Mount the ${ALLINONE}/efi/grub2/grub2_uefi.bin image at ${grub2_uefi_mp} as loop 
 	if ! [ "$(grep ^loop /proc/modules)" ]; then
-		  modprobe -q loop || echo "Your hostsystem has a different kernel version installed, please load loop module first on hostsystem!"
+		modprobe -q loop || echo "Your hostsystem has a different kernel version installed, please load loop module first on hostsystem!"
 	fi
 	LOOP_DEVICE="$(losetup --show --find "${ALLINONE}/efi/grub2/grub2_uefi.bin")"
 	mount -o rw,users -t vfat "${LOOP_DEVICE}" "${grub2_uefi_mp}"
@@ -255,7 +276,7 @@ _prepare_grub2_uefi_iso_files() {
 	umount "${grub2_uefi_mp}"
 	losetup --detach "${LOOP_DEVICE}"
 	
-	cp /usr/share/grub/{unicode,ascii}.pf2 "${ALLINONE}/efi/grub2/"
+	cp /usr/share/grub/unicode.pf2 "${ALLINONE}/efi/grub2/"
 	
 	mkdir -p "${ALLINONE}/efi/grub2/locale/"
 	
@@ -317,13 +338,13 @@ initrd /boot/initrd64.img
 menuentry "Arch Linux LTS (i686) archboot" {
 set root=(\${archboot})
 linux /boot/vmlts ro \${_kernel_params}
-initrd /boot/initrdlts.img
+initrd /boot/initrd.img
 }
 
 menuentry "Arch Linux LTS (x86_64) archboot" {
 set root=(\${archboot})
 linux /boot/vm64lts ro \${_kernel_params}
-initrd /boot/initrd64lts.img
+initrd /boot/initrd64.img
 }
 
 EOF
@@ -334,6 +355,8 @@ _prepare_packages
 
 _prepare_other_files
 
+_merge_initramfs_files
+
 _prepare_kernel_initramfs_files
 
 _prepare_grub2_uefi_iso_files
@@ -347,11 +370,12 @@ sed -i -e "s/@@DATE@@/$(date)/g" -e "s/@@KERNEL@@/$KERNEL/g"  -e "s/@@LTS_KERNEL
 ## Generate the BIOS+UEFI+ISOHYBRID ISO image using xorriso (extra/libisoburn package) in mkisofs emulation mode
 echo "Generating ALLINONE hybrid ISO ..."
 xorriso -as mkisofs \
-        -rock -joliet \
+        -iso-level 3 -rock -joliet \
         -max-iso9660-filenames -omit-period \
         -omit-version-number -allow-leading-dots \
         -relaxed-filenames -allow-lowercase -allow-multidot \
         -volid "ARCHBOOT" \
+        -p "prepared by ${APPNAME}" \
         -eltorito-boot boot/syslinux/isolinux.bin \
         -eltorito-catalog boot/syslinux/boot.cat \
         -no-emul-boot -boot-load-size 4 -boot-info-table \
